@@ -2,7 +2,7 @@
  *  cache.c
  *  mod_musicindex
  *
- *  $Id: cache.c,v 1.46 2004/02/10 17:43:32 varenet Exp $
+ *  $Id: cache.c,v 1.48 2004/06/15 21:15:00 varenet Exp $
  *
  *  Created by Thibaut VARENE on Fri Jul 04 2003.
  *  Copyright (c) 2003-2004 Thibaut VARENE
@@ -26,7 +26,7 @@
  * short cache_write_file(request_rec *, mu_ent *, mu_config *, mu_cache_data *)
  *
  * @author Thibaut Varene
- * @version $Revision: 1.46 $
+ * @version $Revision: 1.48 $
  * @date 2003-2004
  *
  * @warning Under development, not thoroughly tested!
@@ -335,6 +335,8 @@ error_out:
  * This function reads the tags from the cache file
  * and fills in the struct mu_ent fields accordingly.
  * 
+ * @warning <b>MUST</b> close in on success.
+ *
  * @param pool Pool
  * @param head Head
  * @param in Not used (except for closing).
@@ -350,6 +352,7 @@ mu_ent *make_cache_entry(apr_pool_t *pool, mu_ent *head,
 {
 	mu_ent		*p = head;
 	short 		result = 0;
+	unsigned short	cvers = 0;
 	FILE		*cache_file = NULL;
 
 	/* Is cache enabled? */
@@ -394,17 +397,19 @@ mu_ent *make_cache_entry(apr_pool_t *pool, mu_ent *head,
 	result = fscanf(cache_file, "album: %[^\n]\nartist: %[^\n]\n"
 		"title: %[^\n]\ndate: %hu\ntrack: %hu\nposn: %hu\n"
 		"length: %lu\nbitrate: %lu\nsize: %lu\nfiletype: %c\n"
-		"genre: %[^\n]\n",
+		"genre: %[^\n]\nmtime: %lu\ncvers: %hu\n",
 		p->album, p->artist, p->title, &p->date, &p->track, &p->posn, &p->length,
-		&p->bitrate, &p->size, &p->filetype, p->genre);
+		&p->bitrate, &p->size, &p->filetype, p->genre, &p->mtime, &cvers);
 
 	/* Explicitely releasing the lock, and closing the file */
 	flock(fileno(cache_file), LOCK_UN);
 	fclose(cache_file);
 	
-	/* XXX ameliorer le test ici. if (result != NB_FIELDS) ? */
-	if (!result)	/* fscanf() returns the number of input items assigned */
-		return head;
+	/* Check whether the cache is somehow corrupted */
+	if ((result != CACHE_NF) || (cvers < CACHE_VERS)) {	/* fscanf() returns the number of input items assigned */
+		names->create_cache_file = 1;	/* claim we want a cache update */
+		return head;			/* hopefuly p allocs should be cleaned by apache */
+	}
 	
 	if (!strcmp(p->album, "(null)"))
 		p->album[0] = '\0';
@@ -413,7 +418,8 @@ mu_ent *make_cache_entry(apr_pool_t *pool, mu_ent *head,
 	if (!strcmp(p->genre, "(null)"))
 		p->genre[0] = '\0';
 	
-	fclose(in);
+	fclose(in);	/* this part of the cache subsystem is (ugly) seen as part of the playlist system,
+			and has to behave as such. This is why we close the input file if we took advantage of it. */
 	
 	return p;
 	
@@ -459,9 +465,9 @@ short cache_write_file(request_rec *r, mu_ent *p, mu_config *conf, mu_ent_names
 	
 	fprintf(cache_file, "album: %s\nartist: %s\ntitle: %s\ndate: %hu\n"
 		"track: %hu\nposn: %hu\nlength: %lu\nbitrate: %lu\n"
-		"size: %lu\nfiletype: %s\ngenre: %s\n",
+		"size: %lu\nfiletype: %s\ngenre: %s\nmtime: %lu\ncvers: %hu\n",
 		p->album, p->artist, p->title, p->date, p->track, p->posn, p->length,
-		p->bitrate, p->size, &p->filetype, p->genre);
+		p->bitrate, p->size, &p->filetype, p->genre, p->mtime, CACHE_VERS);
 
 	/* Explicitely releasing the lock, and closing the file */
 	flock(fileno(cache_file), LOCK_UN);
