@@ -2,7 +2,7 @@
  *  html.h
  *  mod_musicindex
  *
- *  $Id: html.h,v 1.21 2004/05/27 12:25:15 boudinr Exp $
+ *  $Id: html.h,v 1.24 2004/07/06 17:56:13 varenet Exp $
  *
  *  Created by Thibaut VARENE on Thu Mar 20 2003.
  *  Copyright (c) 2003-2004 Regis BOUDIN
@@ -19,8 +19,9 @@
 #define HTML_H
 
 #include "mod_musicindex.h"
-#include <strings.h>
+#include <string.h>
 #include <unistd.h>
+#include <ctype.h>	/* isdigit() */
 
 #define MAX_PREFIX	256	/**< Maximum expected size of the URL "prefix" (user\@host stuff). */
 #define DIRPERLINE	3	/**< Number of directories to show per line */
@@ -33,6 +34,7 @@ void send_playlist(request_rec *r, mu_ent *p, mu_config *conf);
 void send_foot(request_rec *r, mu_config *conf);
 void send_result(request_rec *r, mu_ent *p, mu_config *conf);
 void send_customlist(request_rec *r, mu_ent *p, mu_config *conf);
+void send_rss(request_rec *r, mu_ent *p, mu_config *conf);
 
 	
 #endif	/* HTML_H */
